<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filtre:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Uçbirim Yazı Tipini Seç</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Yazı Tipi:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Ön İzleme</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>Bookmarks</source>
        <translation>Yer İmleri</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>Keep window open when it loses focus</source>
        <translation>Odağı kaybetse bile pencereyi açık tut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Uçbirimi görmek için &quot;%1&quot;&apos;e basın.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>Aktif Uçbirimi &amp;Temizle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Sonraki Sekme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Önceki Sekme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Geçmişten Önceki Sekmeler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>&amp;Next Tab in History</source>
        <translation>Geçmişten &amp;Sonraki Sekme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="272"/>
        <source>Move Tab &amp;Left</source>
        <translation>Sekmeyi So&amp;la Al</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Move Tab &amp;Right</source>
        <translation>Sekmeyi Sa&amp;ğa Al</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>Tab</source>
        <translation>Sekme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Go to</source>
        <translation>Git</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>Split &amp;View Top-Bottom</source>
        <translation>Bölünmüş Görünüm &amp;Üst-Alt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Split Vie&amp;w Left-Right</source>
        <translation>Bölünmüş Görünüm &amp;Sol-Sağ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>Alt Uçbirimi &amp;Daralt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>&amp;Top Subterminal</source>
        <translation>Alt Uçbirim &amp;Üstte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>Alt Uçbirim &amp;Altta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>L&amp;eft Subterminal</source>
        <translation>Alt Uçbirim So&amp;lda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>R&amp;ight Subterminal</source>
        <translation>Alt Uçbirim Sa&amp;ğda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="321"/>
        <source>Copy &amp;Selection</source>
        <translation>Seçimi &amp;Kopyala</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>Paste Clip&amp;board</source>
        <translation>Panoyu Yap&amp;ıştır</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Paste S&amp;election</source>
        <translation>Seçimi &amp;Yapıştır</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Zoom &amp;in</source>
        <translation>Yakınla&amp;ştır</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Zoom &amp;out</source>
        <translation>Uzaklaşt&amp;ır</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Zoom rese&amp;t</source>
        <translation>&amp;İlk Boyut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="341"/>
        <source>&amp;Find...</source>
        <translation>&amp;Bul...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>Handle history...</source>
        <translation>Geçmişi yönet...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>&amp;Save Session</source>
        <translation>Ot&amp;urumu Kaydet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <source>&amp;Load Session</source>
        <translation>Oturu&amp;mu Yükle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;Geçiş Menüsü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>Rename session</source>
        <translation>Oturumu yeniden adlandır</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Yeni Sekme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="383"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Ön Ay&amp;arlı Yeni Sekme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="384"/>
        <source>1 &amp;Terminal</source>
        <translation>&amp;1 Terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>Yatay &amp;2 Uçbirim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>Dike&amp;y 2 Uçbirim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>4 Terminal&amp;s</source>
        <translation>&amp;4 Uçbirim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Sekmeyi Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>&amp;New Window</source>
        <translation>&amp;Yeni Pencere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Tercihler...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="410"/>
        <source>&amp;Quit</source>
        <translation>&amp;Çıkış</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="416"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Pencere Kenarlıklarını Gizle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>&amp;Show Tab Bar</source>
        <translation>Sekme &amp;Çubuğunu Göster</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="442"/>
        <source>Fullscreen</source>
        <translation>Tam Ekran</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Toggle Bookmarks</source>
        <translation>Yer İmlerini Değiştir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Alt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="457"/>
        <source>&amp;Top</source>
        <translation>&amp;Üst</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>&amp;Right</source>
        <translation>Sa&amp;ğ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>&amp;Left</source>
        <translation>So&amp;l</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="477"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;Sekmelerin Düzeni</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>&amp;None</source>
        <translation>&amp;Hiçbiri</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>S&amp;crollbar Layout</source>
        <translation>&amp;Kaydırma Çubuğu Düzeni</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="524"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Blok İmleç</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <source>&amp;UnderlineCursor</source>
        <translation>Alt Çiz&amp;gi İmleç</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;Işın İmleç</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="543"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Klavye İmleç Şekli</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>Exit QTerminal</source>
        <translation>QTerminal&apos;den Çık</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Do not ask again</source>
        <translation>Tekrar sorma</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>Are you sure you want to exit?</source>
        <translation>Çıkmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="688"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="690"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>Hafif ve güçlü çok platformlu bir terminal emülatörü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="692"/>
        <source>Copyright (C) </source>
        <translation>Telif hakkı (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="692"/>
        <source>2013-2022</source>
        <translation>2013-2022</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="694"/>
        <source>LXQt Project</source>
        <translation>LXQt Projesi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="696"/>
        <source>Development: </source>
        <translation>Geliştirme: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="830"/>
        <source>Emulation</source>
        <translation>Öykünme</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <source>Shortcuts</source>
        <translation>Kısayollar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Uçbirim ayarları</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <location filename="../forms/propertiesdialog.ui" line="581"/>
        <source>Behavior</source>
        <translation>Davranış</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="48"/>
        <source>Dropdown</source>
        <translation>Açılış</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="57"/>
        <source>Bookmarks</source>
        <translation>Yer İmleri</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="272"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Sekme çubuğunu yalnızca bir sekmeyle gizle</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="173"/>
        <source>Color scheme</source>
        <translation>Renk düzeni</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="199"/>
        <source>Scrollbar position</source>
        <translation>Kaydırma çubuğu durumu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="463"/>
        <source>Start with preset:</source>
        <translation>Ön ayarlarla başlat:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Show a border around the current terminal</source>
        <translation>Geçerli uçbirim etrafında bir sınır göster</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="380"/>
        <source>Terminal transparency</source>
        <translation>Uçbirim saydamlığı</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="354"/>
        <source>Application transparency</source>
        <translation>Uygulama şeffaflığı</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="474"/>
        <source>None (single terminal)</source>
        <translation>Hiçbiri (tek terminal)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="479"/>
        <source>2 terminals horizontally</source>
        <translation>Yatay 2 uçbirim</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="484"/>
        <source>2 terminals vertically</source>
        <translation>Dikey 2 uçbirim</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="489"/>
        <source>4 terminals</source>
        <translation>4 uçbirim</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="127"/>
        <source>Font</source>
        <translation>Yazı tipi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="163"/>
        <source>&amp;Change...</source>
        <translation>&amp;Değiştir...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="212"/>
        <source>Tabs position</source>
        <translation>Sekme durumu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="186"/>
        <source>Widget style</source>
        <translation>Parçacık biçimi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Show the menu bar</source>
        <translation>Menü çubuğunu göster</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="316"/>
        <source>Change window title based on current terminal</source>
        <translation>Mevcut uçbirime göre pencere başlığını değiştir</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="323"/>
        <source>Change window icon based on current terminal</source>
        <translation>Mevcut uçbirime göre pencere simgesini değiştir</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="337"/>
        <source>Enable bi-directional text support</source>
        <translation>İki yönlü metin desteğini etkinleştir</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="406"/>
        <source>Background image:</source>
        <translation>Arka Plan resmi:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Select</source>
        <translation>Seç</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="330"/>
        <source>Show terminal size on resize</source>
        <translation>Yeniden boyutlandırıldığında uçbirim boyutunu göster</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="289"/>
        <location filename="../forms/propertiesdialog.ui" line="507"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="306"/>
        <source>Show close button on each tab</source>
        <translation>Her sekmede kapat düğmesini göster</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="497"/>
        <source>Terminal margin</source>
        <translation>Uçbirim kenar boşluğu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Yazı tipi içindeki kutu çizme karakterlerini kullan</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Hızlandırıcılar, Alt ile etkinleşir ve uçbirime müdahale edilebilir.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="251"/>
        <source>No menu bar accelerator</source>
        <translation>Menü çubuğu hızlandırıcısı yok</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="614"/>
        <source>Action after paste</source>
        <translation>Yapıştırdıktan sonraki işlem</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="654"/>
        <source>Confirm multiline paste</source>
        <translation>Çok satırlı yapıştırma işlemini onayla</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="661"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Yapıştırılan son satırları yapıştırılan metinde kırp</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="757"/>
        <source>Open new terminals in current working directory</source>
        <translation>Geçerli çalışma dizininde yeni uçbirimler açın</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="692"/>
        <source>Save Size when closing</source>
        <translation>Kapandığında boyutu kaydet</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="685"/>
        <source>Save Position when closing</source>
        <translation>Kapandığında durumu kaydet</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="678"/>
        <source>Ask for confirmation when closing</source>
        <translation>Kapandığında onay için sor</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="594"/>
        <source>Unlimited history</source>
        <translation>Sınırsız geçmiş</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="587"/>
        <source>History size (in lines)</source>
        <translation>Tarih büyüklüğü (satırlarda)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="781"/>
        <source>Default $TERM</source>
        <translation>Varsayılan $TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="704"/>
        <source>Start with this size:</source>
        <translation>Bu boyutlarla başla:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Background mode:</source>
        <translation>Arka plan modu:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="440"/>
        <source>Stretch</source>
        <translation>Uzatmak</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Zoom</source>
        <translation>Yakınlaştır</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="450"/>
        <source>Fit</source>
        <translation>Uygun</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="455"/>
        <source>Center</source>
        <translation>Merkez</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="344"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Kutu çizimi karakterlerinin Terminal tarafından dahili olarak mı yoksa alttaki yazı tipi oluşturma kütüphaneleri ile mi çizileceğini belirtin.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Yoğun renkler oluşturmak için kalın yazı tipi yüzünün kullanımını değiştirir</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="241"/>
        <source>Use bold font face for intense colors</source>
        <translation>Yoğun renkler için kalın yazı tipi yüzü kullanın</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Pencere Kenarlıklarını Gizle</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="839"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt; &lt;p&gt; Taklit edilecek davranış. Bunun işletim sisteminizle uyuşmasının gerekmediğini unutmayın. &lt;/p&gt; &lt;p&gt; Emin değilseniz &lt;span style = &quot;font-weight: 600;&quot;&gt; varsayılan &lt;/span&gt; öykünmeyi kullanın. &lt;/ P &gt; &lt;/body&gt; &lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="817"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>Bu komut, geri kaydırma geçmişini içeren bir geçici dosyanın dosya adını içeren bir bağımsız değişkenle çalıştırılacaktır</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="820"/>
        <source>Handle history command</source>
        <translation>Geçmiş komutunu işle</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="711"/>
        <location filename="../forms/propertiesdialog.ui" line="725"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="732"/>
        <source>Get current size</source>
        <translation>Mevcut boyutu al</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="767"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Etkin sekmenin sağında yeni sekme aç</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="764"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>İşaretlenmezse, yeni sekme en sağdaki sekme olarak açılacaktır</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="668"/>
        <source>Close tab on middle-click</source>
        <translation>Orta tıklamayla sekmeyi kapat</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="647"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>Basamaklı yapıştırma modunu zorla devre dışı bırakın</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="627"/>
        <source>Word selection characters</source>
        <translation>Kelime seçim karakterleri</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="634"/>
        <source>When selecting text by word, consider these characters as part of words in addition to alphanumeric characters</source>
        <translation>Metni sözcüğe göre seçerken, alfanümerik karakterlere ek olarak bu karakterleri de sözcüklerin bir parçası olarak düşünün</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>:@-./_~</source>
        <translation>:@-./_~</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="644"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>Parantezli yapıştırma modu, çok satırlı dizeleri yapıştırmak için kullanışlıdır.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="774"/>
        <source>Audible bell</source>
        <translation>Sesli zil</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="863"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Bir Kısayolu düzenlemek için:
1. Anahtarına çift tıklayın
2. İstenilen kombinasyona basın ve bırakın
3. Bir Kısayolu tıklayın veya Enter tuşuna basın

Bir Kısayolu kaldırmak/devre dışı bırakmak için, 2. noktada yalnızca bir değiştiriciye (Shift gibi) basın</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="917"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>Kilit tuşunu yatay sekme barında gösterir</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="920"/>
        <source>Keep window open when it loses focus</source>
        <translation>Odağı kaybetse bile pencereyi açık tut</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="938"/>
        <source>Height</source>
        <translation>Yükseklik</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="948"/>
        <location filename="../forms/propertiesdialog.ui" line="965"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="955"/>
        <source>Width</source>
        <translation>Genişlik</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="988"/>
        <source>Note: On Wayland, the shortcut has to be added in the compositor settings for &apos;qterminal -d&apos;.</source>
        <translation>Not: Wayland üzerinde, kısayolun &apos;qterminal -d&apos; için kompozitör ayarlarına eklenmesi gerekir.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1056"/>
        <source>Edit bookmark file contents</source>
        <translation>Yer imi dosyası içeriğini düzenle</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1015"/>
        <source>Enable bookmarks</source>
        <translation>Yer imlerini etkinleştir</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1024"/>
        <source>Bookmark file</source>
        <translation>Yer İmi dosyası</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="910"/>
        <source>Show on start</source>
        <translation>Başlangıçta göster</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>Cursor shape</source>
        <translation>İmleç şekli</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="279"/>
        <source>Fixed tab width:</source>
        <translation>Sabit sekme genişliği:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="927"/>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="979"/>
        <source>Shortcut:</source>
        <translation>Kısayol:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1037"/>
        <source>Find...</source>
        <translation>Bul...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1046"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Kendi yer imleri dosya yolunuzu berlirleyebilirsiniz. Bu, OwnCloud veya Dropbox gibi araçlarla yer imlerinizi paylaşmayı kolaylaştırır.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="364"/>
        <location filename="../forms/propertiesdialog.ui" line="390"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="893"/>
        <source>Shortcut</source>
        <translation>Kısayol</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="898"/>
        <source>Key</source>
        <translation>Anahtar</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="164"/>
        <source>No scrollbar</source>
        <translation>Kaydırma çubuğu yok</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="164"/>
        <location filename="../propertiesdialog.cpp" line="170"/>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="164"/>
        <location filename="../propertiesdialog.cpp" line="170"/>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="170"/>
        <source>Top</source>
        <translation>En Yukarı</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="170"/>
        <source>Bottom</source>
        <translation>En Aşağı</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="183"/>
        <source>BlockCursor</source>
        <translation>Blok İmleç</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="183"/>
        <source>UnderlineCursor</source>
        <translation>Alt Çizgi İmleç</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="183"/>
        <source>IBeamCursor</source>
        <translation>Işın İmleç</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="201"/>
        <source>No move</source>
        <translation>Taşıma yok</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="201"/>
        <source>Scrolling to top</source>
        <translation>En üste kaydırılıyor</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="201"/>
        <source>Scrolling to bottom</source>
        <translation>En alta kaydırılıyor</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="276"/>
        <source>Examples</source>
        <translation>Örnekler</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="430"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>Görüntüler (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="532"/>
        <source>Open bookmarks file</source>
        <translation>Yer imleri dosyasını aç</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="534"/>
        <source>XML files (*.xml)</source>
        <translation>XML dosyası (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="535"/>
        <source>All files (*)</source>
        <translation>Tüm dosyalar (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="634"/>
        <location filename="../propertiesdialog.cpp" line="638"/>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="634"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>Bu yer imleri dosyasının üzerine yazmak istiyor musunuz?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="638"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>Yer imleri dosyasının adı &apos;.xml&apos; ile bitmiyor.
 Üzerine yazmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="646"/>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="646"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>Bu dosyaya yer imleri yazılamıyor:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="211"/>
        <location filename="../propertiesdialog.cpp" line="324"/>
        <source>System Default</source>
        <translation>Sistem Varsayılanı</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="429"/>
        <source>Choose a background image</source>
        <translation>Bir arkaplan resmi seç</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>Eşitlenmiş Yer İmleri</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="81"/>
        <location filename="../tabwidget.cpp" line="235"/>
        <source>Shell No. %1</source>
        <translation>Kabuk No. %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="203"/>
        <source>Tab name</source>
        <translation>Sekme adı</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="204"/>
        <source>New tab name:</source>
        <translation>Yeni sekme adı:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="224"/>
        <source>Select new tab title color</source>
        <translation>Yeni sekme başlık rengini seç</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="253"/>
        <source>Close session</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="255"/>
        <source>Change title color</source>
        <translation>Başlık rengini değiştir</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="77"/>
        <source>Load Session</source>
        <translation>Oturum Yükle</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="78"/>
        <source>List of saved sessions:</source>
        <translation>Kaydedilmiş oturumların listesi:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Ana Pencere</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Dosya</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Eylemler</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Görünüm</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>D&amp;üzen</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;Hakkında...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>&amp;Qt Hakkında...</translation>
    </message>
</context>
</TS>
